try:
    from .progress import Progress  # NOQA
    from .modal import Modal  # NOQA
    from .nodes import *  # NOQA

except ImportError:
    # this happens while packaging and can be ignored

    pass

VERSION = (0, 1, 1)
VERSION_STRING = '{}'.format('.'.join([str(i) for i in VERSION]))



#!/usr/bin/env python
# -*- coding: utf-8 -*-

from setuptools import setup, find_packages

from lona_bootstrap_5 import VERSION_STRING

setup(
    include_package_data=True,
    name='lona-bootstrap-5',
    version=VERSION_STRING,
    author='Florian Scherf',
    url='https://github.com/lona-web-org/lona-bootstrap-5',
    author_email='f.scherf@pengutronix.de',
    license='MIT',
    packages=find_packages(),
    install_requires=[],
)



from lona.static_files import StyleSheet, Script, SORT_ORDER


STATIC_FILES = [
    # css files
    StyleSheet(
        name='bootstrap5.css',
        path='static/bootstrap-5.1.0-dist/css/bootstrap.min.css',
        url='bootstrap5.min.css',
        sort_order=SORT_ORDER.FRAMEWORK,
    ),
    StyleSheet(
        name='bootstrap5.css',
        path='static/bootstrap-5.1.0-dist/css/bootstrap.min.css',
        url='bootstrap5.min.css.map',
        sort_order=SORT_ORDER.FRAMEWORK,
        link=False,
    ),

    # js files
    Script(
        name='bootstrap5.bundle.js',
        path='static/bootstrap-5.1.0-dist/js/bootstrap.bundle.min.js',
        url='bootstrap5.bundle.min.js',
        sort_order=SORT_ORDER.FRAMEWORK,
    ),
    Script(
        name='bootstrap5.bundle.js',
        path='static/bootstrap-5.1.0-dist/js/bootstrap.bundle.min.js.map',
        url='bootstrap5.bundle.min.js.map',
        sort_order=SORT_ORDER.FRAMEWORK,
        link=False,
    ),

    # widgets
    Script(
        name='lona_bootstrap5.widgets',
        path='static/bootstrap5-widgets.js',
        url='bootstrap5-widgets.js',
        sort_order=SORT_ORDER.LIBRARY,
    ),
]


from lona.html import Widget, HTML

from .static_files import STATIC_FILES


class Modal(Widget):
    STATIC_FILES = STATIC_FILES
    FRONTEND_WIDGET_CLASS = 'lona_bootstrap5.Modal'

    def __init__(self, fade=True, scrollable=False, centered=False):
        # setup html
        self.nodes = HTML("""
            <div class="modal" data-bs-backdrop="static" data-bs-keyboard="false" tabindex="-1" aria-hidden="true">
                <div class="modal-dialog">
                    <div class="modal-content">
                        <div class="modal-header">
                            <h5 class="modal-title"></h5>
                            <button type="button" class="btn-close" aria-label="Close"></button>
                        </div>
                        <div class="modal-body"></div>
                        <div class="modal-footer"></div>
                    </div>
                </div>
            </div>
        """)[0]  # NOQA

        self._modal_dialog = self.query_selector('div.modal-dialog')
        self._modal_header = self.query_selector('div.modal-header')
        self._modal_title = self.query_selector('h5.modal-title')
        self._close_button = self.query_selector('button')
        self._modal_body = self.query_selector('div.modal-body')
        self._modal_footer = self.query_selector('div.modal-footer')

        self.close_button = self._modal_header.query_selector(
            'button.btn-close')

        # setup data
        self.data = {
            'modal_options': {
                'focuse': True,
            },
            'visible': False,
        }

        # properties
        self.fade = fade
        self.scrollable = scrollable
        self.centered = centered

    # properties ##############################################################
    # fade
    @property
    def fade(self):
        return 'fade' in self.nodes[0].class_list

    @fade.setter
    def fade(self, new_value):
        if new_value:
            self.nodes[0].class_list.add('fade')

        else:
            self.nodes[0].class_list.remove('fade')

    # scrollable
    @property
    def scrollable(self):
        return 'modal-dialog-scrollable' in self._modal_dialog.class_list

    @scrollable.setter
    def scrollable(self, new_value):
        if new_value:
            self._modal_dialog.class_list.add('modal-dialog-scrollable')

        else:
            self._modal_dialog.class_list.remove('modal-dialog-scrollable')

    # centered
    @property
    def centered(self):
        return 'modal-dialog-centered' in self._modal_dialog.class_list

    @centered.setter
    def centered(self, new_value):
        if new_value:
            self._modal_dialog.class_list.add('modal-dialog-centered')

        else:
            self._modal_dialog.class_list.remove('modal-dialog-centered')

    # methods #################################################################
    def hide(self):
        self.data['visible'] = False

    def show(self):
        self.data['visible'] = True

    def set_title(self, *nodes):
        self._modal_title.nodes = list(nodes)

    def set_body(self, *nodes):
        self._modal_body.nodes = list(nodes)

    def set_buttons(self, *buttons):
        self.buttons = list(buttons)
        self._modal_footer.nodes = self.buttons



from lona.html import (
    TextInput as BaseTextInput,
    TextArea as BaseTextArea,
    Button as BaseButton,
    Div,
)

from .static_files import STATIC_FILES


# inputs ######################################################################
class TextInput(BaseTextInput):
    STATIC_FILES = STATIC_FILES
    CLASS_LIST = ['form-control']


class TextArea(BaseTextArea):
    STATIC_FILES = STATIC_FILES
    CLASS_LIST = ['form-control']


# buttons #####################################################################
class Button(BaseButton):
    STATIC_FILES = STATIC_FILES
    CLASS_LIST = ['btn', 'btn-primary']


class PrimaryButton(Button):
    pass


class SecondaryButton(Button):
    STATIC_FILES = STATIC_FILES
    CLASS_LIST = ['btn', 'btn-secondary']


class SuccessButton(Button):
    STATIC_FILES = STATIC_FILES
    CLASS_LIST = ['btn', 'btn-success']


class DangerButton(Button):
    STATIC_FILES = STATIC_FILES
    CLASS_LIST = ['btn', 'btn-danger']


class WarningButton(Button):
    STATIC_FILES = STATIC_FILES
    CLASS_LIST = ['btn', 'btn-warning']


class InfoButton(Button):
    STATIC_FILES = STATIC_FILES
    CLASS_LIST = ['btn', 'btn-info']


class LightButton(Button):
    STATIC_FILES = STATIC_FILES
    CLASS_LIST = ['btn', 'btn-light']


class DarkButton(Button):
    STATIC_FILES = STATIC_FILES
    CLASS_LIST = ['btn', 'btn-dark']


class LinkButton(Button):
    STATIC_FILES = STATIC_FILES
    CLASS_LIST = ['btn', 'btn-link']


# grid system #################################################################
class Row(Div):
    STATIC_FILES = STATIC_FILES
    CLASS_LIST = ['row']


class Col(Div):
    STATIC_FILES = STATIC_FILES
    CLASS_LIST = ['col']


# XS ##################################
class ColXsAuto(Div):
    STATIC_FILES = STATIC_FILES
    CLASS_LIST = ['col-xs-auto']


class ColXs1(Div):
    STATIC_FILES = STATIC_FILES
    CLASS_LIST = ['col-xs-1']


class ColXs2(Div):
    STATIC_FILES = STATIC_FILES
    CLASS_LIST = ['col-xs-2']


class ColXs3(Div):
    STATIC_FILES = STATIC_FILES
    CLASS_LIST = ['col-xs-3']


class ColXs4(Div):
    STATIC_FILES = STATIC_FILES
    CLASS_LIST = ['col-xs-4']


class ColXs5(Div):
    STATIC_FILES = STATIC_FILES
    CLASS_LIST = ['col-xs-5']


class ColXs6(Div):
    STATIC_FILES = STATIC_FILES
    CLASS_LIST = ['col-xs-6']


class ColXs7(Div):
    STATIC_FILES = STATIC_FILES
    CLASS_LIST = ['col-xs-7']


class ColXs8(Div):
    STATIC_FILES = STATIC_FILES
    CLASS_LIST = ['col-xs-8']


class ColXs9(Div):
    STATIC_FILES = STATIC_FILES
    CLASS_LIST = ['col-xs-9']


class ColXs10(Div):
    STATIC_FILES = STATIC_FILES
    CLASS_LIST = ['col-xs-10']


class ColXs11(Div):
    STATIC_FILES = STATIC_FILES
    CLASS_LIST = ['col-xs-11']


class ColXs12(Div):
    STATIC_FILES = STATIC_FILES
    CLASS_LIST = ['col-xs-12']


# SM ##################################
class ColSmAuto(Div):
    STATIC_FILES = STATIC_FILES
    CLASS_LIST = ['col-sm-auto']


class ColSm1(Div):
    STATIC_FILES = STATIC_FILES
    CLASS_LIST = ['col-sm-1']


class ColSm2(Div):
    STATIC_FILES = STATIC_FILES
    CLASS_LIST = ['col-sm-2']


class ColSm3(Div):
    STATIC_FILES = STATIC_FILES
    CLASS_LIST = ['col-sm-3']


class ColSm4(Div):
    STATIC_FILES = STATIC_FILES
    CLASS_LIST = ['col-sm-4']


class ColSm5(Div):
    STATIC_FILES = STATIC_FILES
    CLASS_LIST = ['col-sm-5']


class ColSm6(Div):
    STATIC_FILES = STATIC_FILES
    CLASS_LIST = ['col-sm-6']


class ColSm7(Div):
    STATIC_FILES = STATIC_FILES
    CLASS_LIST = ['col-sm-7']


class ColSm8(Div):
    STATIC_FILES = STATIC_FILES
    CLASS_LIST = ['col-sm-8']


class ColSm9(Div):
    STATIC_FILES = STATIC_FILES
    CLASS_LIST = ['col-sm-9']


class ColSm10(Div):
    STATIC_FILES = STATIC_FILES
    CLASS_LIST = ['col-sm-10']


class ColSm11(Div):
    STATIC_FILES = STATIC_FILES
    CLASS_LIST = ['col-sm-11']


class ColSm12(Div):
    STATIC_FILES = STATIC_FILES
    CLASS_LIST = ['col-sm-12']


# MD ##################################
class ColMdAuto(Div):
    STATIC_FILES = STATIC_FILES
    CLASS_LIST = ['col-md-auto']


class ColMd1(Div):
    STATIC_FILES = STATIC_FILES
    CLASS_LIST = ['col-md-1']


class ColMd2(Div):
    STATIC_FILES = STATIC_FILES
    CLASS_LIST = ['col-md-2']


class ColMd3(Div):
    STATIC_FILES = STATIC_FILES
    CLASS_LIST = ['col-md-3']


class ColMd4(Div):
    STATIC_FILES = STATIC_FILES
    CLASS_LIST = ['col-md-4']


class ColMd5(Div):
    STATIC_FILES = STATIC_FILES
    CLASS_LIST = ['col-md-5']


class ColMd6(Div):
    STATIC_FILES = STATIC_FILES
    CLASS_LIST = ['col-md-6']


class ColMd7(Div):
    STATIC_FILES = STATIC_FILES
    CLASS_LIST = ['col-md-7']


class ColMd8(Div):
    STATIC_FILES = STATIC_FILES
    CLASS_LIST = ['col-md-8']


class ColMd9(Div):
    STATIC_FILES = STATIC_FILES
    CLASS_LIST = ['col-md-9']


class ColMd10(Div):
    STATIC_FILES = STATIC_FILES
    CLASS_LIST = ['col-md-10']


class ColMd11(Div):
    STATIC_FILES = STATIC_FILES
    CLASS_LIST = ['col-md-11']


class ColMd12(Div):
    STATIC_FILES = STATIC_FILES
    CLASS_LIST = ['col-md-12']


# LG ##################################
class ColLgAuto(Div):
    STATIC_FILES = STATIC_FILES
    CLASS_LIST = ['col-lg-auto']


class ColLg1(Div):
    STATIC_FILES = STATIC_FILES
    CLASS_LIST = ['col-lg-1']


class ColLg2(Div):
    STATIC_FILES = STATIC_FILES
    CLASS_LIST = ['col-lg-2']


class ColLg3(Div):
    STATIC_FILES = STATIC_FILES
    CLASS_LIST = ['col-lg-3']


class ColLg4(Div):
    STATIC_FILES = STATIC_FILES
    CLASS_LIST = ['col-lg-4']


class ColLg5(Div):
    STATIC_FILES = STATIC_FILES
    CLASS_LIST = ['col-lg-5']


class ColLg6(Div):
    STATIC_FILES = STATIC_FILES
    CLASS_LIST = ['col-lg-6']


class ColLg7(Div):
    STATIC_FILES = STATIC_FILES
    CLASS_LIST = ['col-lg-7']


class ColLg8(Div):
    STATIC_FILES = STATIC_FILES
    CLASS_LIST = ['col-lg-8']


class ColLg9(Div):
    STATIC_FILES = STATIC_FILES
    CLASS_LIST = ['col-lg-9']


class ColLg10(Div):
    STATIC_FILES = STATIC_FILES
    CLASS_LIST = ['col-lg-10']


class ColLg11(Div):
    STATIC_FILES = STATIC_FILES
    CLASS_LIST = ['col-lg-11']


class ColLg12(Div):
    STATIC_FILES = STATIC_FILES
    CLASS_LIST = ['col-lg-12']


# XL ##################################
class ColXlAuto(Div):
    STATIC_FILES = STATIC_FILES
    CLASS_LIST = ['col-xl-auto']


class ColXl1(Div):
    STATIC_FILES = STATIC_FILES
    CLASS_LIST = ['col-xl-1']


class ColXl2(Div):
    STATIC_FILES = STATIC_FILES
    CLASS_LIST = ['col-xl-2']


class ColXl3(Div):
    STATIC_FILES = STATIC_FILES
    CLASS_LIST = ['col-xl-3']


class ColXl4(Div):
    STATIC_FILES = STATIC_FILES
    CLASS_LIST = ['col-xl-4']


class ColXl5(Div):
    STATIC_FILES = STATIC_FILES
    CLASS_LIST = ['col-xl-5']


class ColXl6(Div):
    STATIC_FILES = STATIC_FILES
    CLASS_LIST = ['col-xl-6']


class ColXl7(Div):
    STATIC_FILES = STATIC_FILES
    CLASS_LIST = ['col-xl-7']


class ColXl8(Div):
    STATIC_FILES = STATIC_FILES
    CLASS_LIST = ['col-xl-8']


class ColXl9(Div):
    STATIC_FILES = STATIC_FILES
    CLASS_LIST = ['col-xl-9']


class ColXl10(Div):
    STATIC_FILES = STATIC_FILES
    CLASS_LIST = ['col-xl-10']


class ColXl11(Div):
    STATIC_FILES = STATIC_FILES
    CLASS_LIST = ['col-xl-11']


class ColXl12(Div):
    STATIC_FILES = STATIC_FILES
    CLASS_LIST = ['col-xl-12']


# XXL #################################
class ColXxlAuto(Div):
    STATIC_FILES = STATIC_FILES
    CLASS_LIST = ['col-xxl-auto']


class ColXxl1(Div):
    STATIC_FILES = STATIC_FILES
    CLASS_LIST = ['col-xxl-1']


class ColXxl2(Div):
    STATIC_FILES = STATIC_FILES
    CLASS_LIST = ['col-xxl-2']


class ColXxl3(Div):
    STATIC_FILES = STATIC_FILES
    CLASS_LIST = ['col-xxl-3']


class ColXxl4(Div):
    STATIC_FILES = STATIC_FILES
    CLASS_LIST = ['col-xxl-4']


class ColXxl5(Div):
    STATIC_FILES = STATIC_FILES
    CLASS_LIST = ['col-xxl-5']


class ColXxl6(Div):
    STATIC_FILES = STATIC_FILES
    CLASS_LIST = ['col-xxl-6']


class ColXxl7(Div):
    STATIC_FILES = STATIC_FILES
    CLASS_LIST = ['col-xxl-7']


class ColXxl8(Div):
    STATIC_FILES = STATIC_FILES
    CLASS_LIST = ['col-xxl-8']


class ColXxl9(Div):
    STATIC_FILES = STATIC_FILES
    CLASS_LIST = ['col-xxl-9']


class ColXxl10(Div):
    STATIC_FILES = STATIC_FILES
    CLASS_LIST = ['col-xxl-10']


class ColXxl11(Div):
    STATIC_FILES = STATIC_FILES
    CLASS_LIST = ['col-xxl-11']


class ColXxl12(Div):
    STATIC_FILES = STATIC_FILES
    CLASS_LIST = ['col-xxl-12']



from lona.html import Node, Div

from .static_files import STATIC_FILES


class Progress(Node):
    STATIC_FILES = STATIC_FILES

    TAG_NAME = 'div'
    CLASS_LIST = ['progress']

    def __init__(self, *label, background=None, value=None, percentage=None,
                 striped=False, animated=False, **kwargs):

        super().__init__(**kwargs)

        self.nodes = [
            Div(
                _class='progress-bar',
                _role='progressbar',
                _aria_valuemin='0',
                _aria_valuemax='100',
            ),
        ]

        if label:
            self.set_label(*label)

        if background is not None:
            self.background = background

        if value is not None:
            self.value = value

        if percentage is not None:
            self.set_percentage(percentage)

        self.striped = striped
        self.animated = animated

    # properties ##############################################################
    # value
    @property
    def value(self):
        return int(self.nodes[0].attributes.get('aria-valuenow', '0'))

    @value.setter
    def value(self, new_value):
        with self.lock:
            self._value = int(new_value)

            self.nodes[0].style['width'] = '{}%'.format(self._value)
            self.nodes[0].attributes['aria-valuenow'] = str(self._value)

    # background
    @property
    def background(self):
        with self.lock:
            for class_name in self.nodes[0].class_list:
                if class_name.startswith['bg-']:
                    return class_name

            return ''

    @background.setter
    def background(self, new_value):
        with self.lock:
            for class_name in self.nodes[0].class_list:
                if class_name.startswith('bg-'):
                    self.nodes[0].class_list.remove(class_name)

            if new_value:
                if not new_value.startswith('bg-'):
                    new_value = 'bg-{}'.format(new_value)

                self.nodes[0].class_list.add(new_value)

    # striped
    @property
    def striped(self):
        return 'progress-bar-striped' in self.nodes[0].class_list

    @striped.setter
    def striped(self, new_value):
        if new_value:
            self.nodes[0].class_list.add('progress-bar-striped')

        else:
            self.nodes[0].class_list.remove('progress-bar-striped')

    # animated
    @property
    def animated(self):
        return 'progress-bar-animated' in self.nodes[0].class_list

    @animated.setter
    def animated(self, new_value):
        if new_value:
            self.nodes[0].class_list.add('progress-bar-animated')

        else:
            self.nodes[0].class_list.remove('progress-bar-animated')

    # methods #################################################################
    def set_label(self, *nodes):
        self.nodes[0].set_text()

    def set_percentage(self, percentage):
        with self.lock:
            self.value = percentage
            self.nodes[0].set_text('{}%'.format(percentage))
